package com.commonsware.liveagreement

import android.os.Bundle
import androidx.activity.viewModels
import androidx.appcompat.app.AppCompatActivity
import androidx.compose.Composable
import androidx.ui.core.Alignment
import androidx.ui.core.Modifier
import androidx.ui.core.setContent
import androidx.ui.foundation.Text
import androidx.ui.layout.Arrangement
import androidx.ui.layout.Column
import androidx.ui.layout.Row
import androidx.ui.layout.Spacer
import androidx.ui.layout.padding
import androidx.ui.layout.preferredHeight
import androidx.ui.layout.preferredWidth
import androidx.ui.livedata.observeAsState
import androidx.ui.material.Checkbox
import androidx.ui.material.MaterialTheme
import androidx.ui.unit.dp

class MainActivity : AppCompatActivity() {
  private val motor: MainMotor by viewModels()

  override fun onCreate(savedInstanceState: Bundle?) {
    super.onCreate(savedInstanceState)

    setContent { AgreementDemo() }
  }

  @Composable
  fun Agreement() {
    Column(
      verticalArrangement = Arrangement.SpaceAround,
      horizontalGravity = Alignment.CenterHorizontally,
      modifier = Modifier.padding(8.dp)
    ) {
      val viewState = motor.states.observeAsState(MainMotor.INITIAL_STATE)

      Column(horizontalGravity = Alignment.Start) {
        Row(horizontalArrangement = Arrangement.Start) {
          Checkbox(
            checked = viewState.value.terms,
            onCheckedChange = { motor.onTermsChange(it) }
          )
          Spacer(modifier = Modifier.preferredWidth(4.dp))
          Text(text = "I agree to the terms and conditions")
        }

        Spacer(modifier = Modifier.preferredHeight(8.dp))

        Row(horizontalArrangement = Arrangement.Start) {
          Checkbox(
            checked = viewState.value.privacy,
            onCheckedChange = { motor.onPrivacyChange(it) }
          )
          Spacer(modifier = Modifier.preferredWidth(4.dp))
          Text(text = "I agree to the privacy policy")
        }

        Spacer(modifier = Modifier.preferredHeight(8.dp))

        Text(text = if (viewState.value.canProceed) "You may proceed!" else "Please indicate your agreement")
      }
    }
  }

  @Composable
  fun AgreementDemo() {
    MaterialTheme {
      Agreement()
    }
  }
}
